===============================
IoTronic Panels
===============================

Iotronic plugin for the OpenStack Dashboard

* Free software: Apache license
* Source: http://git.openstack.org/cgit/openstack/iotronic_ui
* Bugs: http://bugs.launchpad.net/None

Features
--------

* TODO

User Documentation
------------------

.. toctree::
   :maxdepth: 2

   install/index
   configuration/index
   Release Notes <https://docs.openstack.org/releasenotes/iotronic_ui>

Contributor Guide
-----------------

.. toctree::
   :glob:
   :maxdepth: 2

   contributor/index
